'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _uuid = require('uuid');

exports.default = function (context) {
  var ellipse = null;
  var imageData = null;

  var onMouseDown = function onMouseDown(x, y, color, size, fill) {
    ellipse = {
      id: (0, _uuid.v4)(),
      tool: 'ELLIPSE',
      color: color,
      size: size,
      fill: fill,
      start: { x: x, y: y },
      end: null
    };
    imageData = context.getImageData(0, 0, context.canvas.clientWidth, context.canvas.clientHeight);
    return [ellipse];
  };

  var drawEllipse = function drawEllipse(mouseX, mouseY) {
    var startX = mouseX < ellipse.start.x ? mouseX : ellipse.start.x;
    var startY = mouseY < ellipse.start.y ? mouseY : ellipse.start.y;
    var endX = mouseX >= ellipse.start.x ? mouseX : ellipse.start.x;
    var endY = mouseY >= ellipse.start.y ? mouseY : ellipse.start.y;

    var radiusX = (endX - startX) * 0.5;
    var radiusY = (endY - startY) * 0.5;
    var centerX = startX + radiusX;
    var centerY = startY + radiusY;

    context.beginPath();
    context.lineWidth = ellipse.size;
    context.strokeStyle = ellipse.color;
    context.fillStyle = ellipse.fill;
    context.ellipse(centerX, centerY, radiusX, radiusY, 0, 0, 2 * Math.PI);
    context.stroke();
    if (ellipse.fill) context.fill();
  };

  var onMouseMove = function onMouseMove(x, y) {
    if (!ellipse) return;
    context.putImageData(imageData, 0, 0);
    context.save();
    drawEllipse(x, y);
    context.restore();
  };

  var onMouseUp = function onMouseUp(x, y) {
    if (!ellipse) return;
    onMouseMove(x, y);
    var item = ellipse;
    imageData = null;
    ellipse = null;
    item.end = { x: x, y: y };
    return [item];
  };

  return {
    onMouseDown: onMouseDown,
    onMouseMove: onMouseMove,
    onMouseUp: onMouseUp
  };
};