'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _uuid = require('uuid');

exports.default = function (context) {
  var currentLine = null;
  var imageData = null;

  var onMouseDown = function onMouseDown(x, y, color, size) {
    currentLine = {
      id: (0, _uuid.v4)(),
      tool: 'LINE',
      color: color,
      size: size,
      start: { x: x, y: y },
      end: null
    };
    imageData = context.getImageData(0, 0, context.canvas.clientWidth, context.canvas.clientHeight);
    return [currentLine];
  };

  var onMouseMove = function onMouseMove(x, y) {
    if (!currentLine) return;
    context.putImageData(imageData, 0, 0);
    context.save();
    context.lineJoin = 'round';
    context.lineCap = 'round';
    context.beginPath();
    context.lineWidth = currentLine.size;
    context.strokeStyle = currentLine.color;
    context.globalCompositeOperation = 'source-over';
    context.moveTo(currentLine.start.x, currentLine.start.y);
    context.lineTo(x, y);
    context.closePath();
    context.stroke();
    context.restore();
  };

  var onMouseUp = function onMouseUp(x, y) {
    if (!currentLine) return;
    onMouseMove(x, y);
    var line = currentLine;
    imageData = null;
    currentLine = null;
    line.end = { x: x, y: y };
    return [line];
  };

  return {
    onMouseDown: onMouseDown,
    onMouseMove: onMouseMove,
    onMouseUp: onMouseUp
  };
};