'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _uuid = require('uuid');

exports.default = function (context) {
  var rectangle = null;
  var imageData = null;

  var onMouseDown = function onMouseDown(x, y, color, size, fill) {
    rectangle = {
      id: (0, _uuid.v4)(),
      tool: 'RECTANGLE',
      color: color,
      size: size,
      fill: fill,
      start: { x: x, y: y },
      end: null
    };
    imageData = context.getImageData(0, 0, context.canvas.clientWidth, context.canvas.clientHeight);
    return [rectangle];
  };

  var drawRectangle = function drawRectangle(mouseX, mouseY) {
    var startX = mouseX < rectangle.start.x ? mouseX : rectangle.start.x;
    var startY = mouseY < rectangle.start.y ? mouseY : rectangle.start.y;
    var widthX = Math.abs(rectangle.start.x - mouseX);
    var widthY = Math.abs(rectangle.start.y - mouseY);

    context.beginPath();
    context.lineWidth = rectangle.size;
    context.strokeStyle = rectangle.color;
    context.fillStyle = rectangle.fill;
    context.rect(startX, startY, widthX, widthY);
    context.stroke();
    if (rectangle.fill) context.fill();
  };

  var onMouseMove = function onMouseMove(x, y) {
    if (!rectangle) return;
    context.putImageData(imageData, 0, 0);
    context.save();
    drawRectangle(x, y);
    context.restore();
  };

  var onMouseUp = function onMouseUp(x, y) {
    if (!rectangle) return;
    onMouseMove(x, y);
    var item = rectangle;
    imageData = null;
    rectangle = null;
    item.end = { x: x, y: y };
    return [item];
  };

  return {
    onMouseDown: onMouseDown,
    onMouseMove: onMouseMove,
    onMouseUp: onMouseUp
  };
};